@@ -127,6 +127,8 @@ class UseCaseDefinition(UCEmulator):
                         print r
                         print ke
                         print '-------------------- KeyError in return of list_replicas ----------------'
+                        monitor.record_counter('emulator.exceptions.panda.CREATE_TASK.KeyError', 1)
+                        files.append({'scope': r['scope'], 'name': r['name'], 'bytes': 0})
                     if ('max_jobs' in input.keys()) and (len(files) > (input['max_jobs'] * input['number_of_inputfiles_per_job'])):
                         monitor.record_counter('panda.tasks.%s.limited_input' % task_type, 1)
                         break
@@ -216,8 +218,8 @@ class UseCaseDefinition(UCEmulator):
                     time.sleep(randint(1, 2))
             for i in range(output_datasets_per_datatype):
                 final_dss[fds].update({'guid': str(uuid())})
-                dsn = '%s.%s' % (fds, i)
-                out_ds = {'scope': output['scope'], 'name': dsn, 'dids': [], 'meta': final_dss[fds].copy(),
+                dsn2 = '%s.%s' % (fds, i)
+                out_ds = {'scope': output['scope'], 'name': dsn2, 'dids': [], 'meta': final_dss[fds].copy(),
                           'rules': [{'account': output['account'], 'copies': 1, 'rse_expression': target_rses[i], 'grouping': 'DATASET', 'lifetime': output['lifetime']}]}
                 temp.append(out_ds)
                 if not bulk:
@@ -239,7 +241,7 @@ class UseCaseDefinition(UCEmulator):
                     while not success:
                         try:
                             with monitor.record_timer_block('panda.add_datasets_to_container'):
-                                client.add_datasets_to_container(scope=output['scope'], name='cnt_%s' % (fds), dsns=[{'scope': output['scope'], 'name': dsn}])
+                                client.add_datasets_to_container(scope=output['scope'], name='cnt_%s' % (fds), dsns=[{'scope': output['scope'], 'name': dsn2}])
                             success = True
                         except (DatabaseException, ConnectionError):
                             monitor.record_counter('panda.retry.add_datasets_to_container.%s' % (retry), 1)
@@ -504,9 +506,9 @@ class UseCaseDefinition(UCEmulator):
                                                                                                                                                             output['scope'], len(inserts_dis),
                                                                                                                                                             len(inserts_sub), len(sub_finish), log_ds,
                                                                                                                                                             final_dss, job_count, len(job_finish) * output_datasets_per_datatype)
-        #print '-', job_finish
-        #print '-', sub_finish
-        #print '-', task_finish
+        # print '-', job_finish
+        # print '-', sub_finish
+        # print '-', task_finish
         return {'jobs': job_finish, 'subs': sub_finish.values(), 'task': task_finish}
 
     def add_files_ds(self, client, ds, ret=None, sem=None):
@@ -549,8 +551,8 @@ class UseCaseDefinition(UCEmulator):
 
     def CREATE_TASK_input(self, ctx):
         try:
-        # Select input DS from file provided by Cedric using observed age distribution from Thomas
-        # Select task type
+            # Select input DS from file provided by Cedric using observed age distribution from Thomas
+            # Select task type
             success = False
             task_type = ''
             while not success:
@@ -558,7 +560,7 @@ class UseCaseDefinition(UCEmulator):
                     while not exit:
                         tt = choice(ctx.task_distribution)
                         exit = (tt.startswith(task_type.split('-')[0]) or (task_type is ''))
-                    #print '== PanDA [%s]: Selecting task from group %s' % (time.strftime('%D %H:%M:%S', time.localtime()), tt.split('-')[0])
+                    # print '== PanDA [%s]: Selecting task from group %s' % (time.strftime('%D %H:%M:%S', time.localtime()), tt.split('-')[0])
                     task_type = tt
                     ret = {'input': ctx.tasks[task_type]['input'],
                            'output': ctx.tasks[task_type]['output'],
@@ -704,7 +706,7 @@ class UseCaseDefinition(UCEmulator):
                 success = True
             except DatabaseException:
                 e = sys.exc_info()
-                monitor.record_counter('panda.retry.add_files_to_dataset.%s' % (retry), 1)
+                monitor.record_counter('panda.retry.panda.attach_dids_to_dids.%s' % (retry), 1)
                 retry += 1
                 if retry > 5:
                     break
@@ -731,10 +733,11 @@ class UseCaseDefinition(UCEmulator):
             print '-' * 80
             if ret:
                 ret.put((False, e))
-        monitor.record_counter('panda.tasks.%s.replicas' % job['task_type'], count)  # Reports the creation of a new replica (including log files) fof the given task type
-        print '== PanDA: Job (%s) added %s files to %s datasets (%s:%s)' % (job['task_type'], count, len(job['targets']), job['scope'], job['targets'])
-        if ret:
-            ret.put((True, count))
+        else:
+            monitor.record_counter('panda.tasks.%s.replicas' % job['task_type'], count)  # Reports the creation of a new replica (including log files) fof the given task type
+            print '== PanDA: Job (%s) added %s files to %s datasets (%s:%s)' % (job['task_type'], count, len(job['targets']), job['scope'], job['targets'])
+            if ret:
+                ret.put((True, count))
 
     def FINISH_JOB_input(self, ctx):
         ctx.job_print += 1
@@ -885,51 +888,51 @@ class UseCaseDefinition(UCEmulator):
                     raise
 
         # Append files to TID
-        try:
-            if sem:
-                sem.acquire()
-            success = False
-            retry = 1
-            while not success:
+        success = False
+        retry = 1
+        while not success:
+            try:
+                if sem:
+                    sem.acquire()
                 with monitor.record_timer_block(['panda.add_files_to_dataset', ('panda.add_files_to_dataset.normalized', len(fs))]):
                     client.add_files_to_dataset(scope=target['scope'], name=target['name'], files=fs)
                 success = True
-        except Exception:
-            exc = sys.exc_info()
-            print '== PanDA: Waiting 5 seconds for task data to arrive in %s (retry count: %s / task-type: %s)' % (source, retry, task_type)
-            monitor.record_counter('panda.retry.add_files_to_dataset.%s' % (retry), 1)
-            retry += 1
-            if retry > 5:
-                if ret:
-                    ret.put((False, exc))
-                return
-        finally:
-            if sem:
-                sem.release()
-        print '== PanDA [%s]: Populated %s files from %s to %s' % (time.strftime('%D %H:%M:%S', time.localtime()), len(fs), source, target)
+            except Exception:
+                exc = sys.exc_info()
+                print '== PanDA: Waiting 5 seconds for task data to arrive in %s (retry count: %s / task-type: %s)' % (source, retry, task_type)
+                monitor.record_counter('panda.retry.add_files_to_dataset.%s' % (retry), 1)
+                retry += 1
+                if retry > 5:
+                    if ret:
+                        ret.put((False, exc))
+                    return
+            finally:
+                if sem:
+                    sem.release()
+            print '== PanDA [%s]: Populated %s files from %s to %s' % (time.strftime('%D %H:%M:%S', time.localtime()), len(fs), source, target)
 
         # Close SUB dataset
-        try:
-            if sem:
-                sem.acquire()
-            success = False
-            retry = 1
-            while not success:
+        success = False
+        retry = 1
+        while not success:
+            try:
+                if sem:
+                    sem.acquire()
                 with monitor.record_timer_block('panda.close'):
                     client.close(**source)
                 success = True
-        except DatabaseException:
-            exc = sys.exc_info()
-            print '== PanDA: Waiting 5 seconds for task data to arrive in %s (retry count: %s / task-type: %s)' % (source, retry, task_type)
-            monitor.record_counter('panda.retry.close.%s' % (retry), 1)
-            retry += 1
-            if retry > 5:
-                if ret:
-                    ret.put((False, exc))
-                return
-        finally:
-            if sem:
-                sem.release()
+            except DatabaseException:
+                exc = sys.exc_info()
+                print '== PanDA: Waiting 5 seconds for task data to arrive in %s (retry count: %s / task-type: %s)' % (source, retry, task_type)
+                monitor.record_counter('panda.retry.close.%s' % (retry), 1)
+                retry += 1
+                if retry > 5:
+                    if ret:
+                        ret.put((False, exc))
+                    return
+            finally:
+                if sem:
+                    sem.release()
         print '== PanDA [%s]: Closed sub dataset: %s' % (time.strftime('%D %H:%M:%S', time.localtime()), source)
         if ret:
             ret.put((True, None))
@@ -1012,7 +1015,7 @@ class UseCaseDefinition(UCEmulator):
         else:
             threads = int(ctx.threads)
         if len(tasks):
-            #print '== PanDA [%s]: Finishing %s tasks.' % (time.strftime('%D %H:%M:%S', time.localtime()), len(tasks))
+            # print '== PanDA [%s]: Finishing %s tasks.' % (time.strftime('%D %H:%M:%S', time.localtime()), len(tasks))
             monitor.record_counter('panda.helper.tasks_block', len(tasks))
             return {'tasks': tasks, 'threads': threads, 'safety_delay': ctx.safety_delay}
         else:
